Slot: slots - LinkML Model

# Slot: slots

list of slot names that are applicable to a class

URI: linkml:slots

## Domain and Range

ClassDefinition → 0..* SlotDefinition

## Parents

## Children

## Used by

- ClassDefinition

## Other properties

Comments: |  | This defines the set of slots that are allowed to be used for a given class. The final list of slots for a class is the combination of the parent (is a) slots, mixins slots, apply to slots minus the slot usage entries. Formally,